# Summary

One-liner – What does this plugin contribution add or change?

## Links

- Plugin documentation:
- Issue link (if applicable):
- Other useful links:

## Plugin Documentation Checklist

- README Validation
    - [ ] Clear installation instructions
    - [ ] Usage examples with code snippets
    - [ ] List of features and capabilities
    - [ ] Troubleshooting guide (if applicable)
    - [ ] Contribution guidelines (if applicable)

- Metadata Validation
    - [ ] Complete metadata provided in reference to [plugin metadata template](../.././plugins/plugin_metadata_template.yml)

## Dev Testing

(Include where applicable)

- Screenshots/GIFs
- Video Demonstrations
- Logs or Console Outputs
- Testing steps for the plugin

## Additional Notes

- Any considerations for future updates or enhancements.
- Known issues or limitations with this plugin contribution.
